@@ -151,18 +151,18 @@ sub build_binaries {
   
   #possible targets:  im im_process im_jp2 im_fftw im_capture im_avi im_wmv
   #possible targets:  cd_zlib cd_freetype cd_ftgl cd cd_pdflib cdpdf cdgl cdcontextplus cdcairo
-  #possible targets:  iup iupcd iupcontrols iup_pplot iup_mglplot iupgl iupim iupimglib iupweb iuptuio
+  #possible targets:  iup iupcd iupcontrols iup_pplot iup_mglplot iupgl iupim iupimglib iupweb iuptuio iup_plot
   
   if ($self->notes('is_devel_cvs_version')) {
     ### DEVEL BUILD ###
     @imtargets  = qw[im im_process im_jp2 im_fftw im_capture];
     @cdtargets  = qw[cd_zlib cd_freetype cd_ftgl cd cd_pdflib cdpdf cdgl]; #xxx add cdcontextplus
-    @iuptargets = qw[iup iupcd iupcontrols iupmatrixex iup_pplot iup_mglplot iupgl iupglcontrols iup_scintilla iupim iupimglib iupweb iuptuio];
+    @iuptargets = qw[iup iupcd iupcontrols iupmatrixex iup_pplot iup_mglplot iupgl iupglcontrols iup_scintilla iupim iupimglib iupweb iuptuio iup_plot];
   }
   else {
     @imtargets  = qw[im];
     @cdtargets  = qw[cd_zlib cd_freetype cd];
-    @iuptargets = qw[iup iupcd iupcontrols iupmatrixex iup_pplot iup_mglplot iupgl iupglcontrols iup_scintilla iupim iupimglib];
+    @iuptargets = qw[iup iupcd iupcontrols iupmatrixex iup_pplot iup_mglplot iupgl iupglcontrols iup_scintilla iupim iupimglib iup_plot];
     #if ($^O eq 'openbsd') {
     #  warn "###WARN### skipping im_process on OpenBSD";
     #  @imtargets = grep { $_ !~ /^im_process$/ } @imtargets;
@@ -171,6 +171,7 @@ sub build_binaries {
     #  warn "###WARN### skipping iuptuio on Solaris";
     #  @iuptargets = grep { $_ !~ /^iuptuio$/ } @iuptargets;
     #}
+
     if ($^O eq 'solaris') {
       warn "###WARN### skipping iup_mglplot on Solaris (fails to compile)";
       @iuptargets = grep { $_ !~ /^iup_mglplot$/ } @iuptargets;
